#include <iostream>
#include <QApplication>
#include <osg/Geode>
#include <osg/Geometry>
#include <osgDB/ReadFile>
#include <osgUtil/SmoothingVisitor>
#include <osgUtil/Optimizer>
#include <osg/io_utils>

#include "Image.h"
#include "Util.h"
#include "Viewer.h" // PoLAR::Viewer header

int main(int argc, char** argv)
{
	QApplication app(argc, argv);

	PoLAR::Viewer viewer(0, "Mon Salon", 0, true);
	viewer.addLightSource(20, 10, 10, true);

	osg::ref_ptr<PoLAR::Image<unsigned char> >
		monImage = new PoLAR::Image<unsigned char>("../data/PhotoPersoMini.jpg", true);
	viewer.setBgImage(monImage);
	viewer.bgImageOn();

	viewer.resize(monImage->getWidth(), monImage->getHeight());

	osg::Matrixd P = PoLAR::Util::readProjectionMatrix("../data/matrice.txt");
	viewer.setProjection(P);

	osg::ref_ptr<osg::Node> vase = osgDB::readNodeFile("../data/calla_lily_with_roses.obj");
	osgUtil::SmoothingVisitor smooth;
	osgUtil::Optimizer optimizer;
	optimizer.optimize(vase.get());
	vase->accept(smooth);

	PoLAR::Object3D* obj = new PoLAR::Object3D(vase.get(), true);
	viewer.addObject3D(obj);
	obj->setEditOn();
	obj->translate(30, 3.5, 0);
	obj->scale(1.3);
	obj->rotate(-0.2, 0, 1, 0);
	obj->setEditOff();

	osg::ref_ptr<osg::Geode> floorGeode = new osg::Geode;
	osg::ref_ptr<osg::ShapeDrawable> shape;
	shape = new osg::ShapeDrawable(new osg::Box(osg::Vec3(0.5f, 0.5f, 0.0f), 5.0f, 5.0f,0.00001f));
	floorGeode->addDrawable(shape.get());
	PoLAR::Object3D* sol = new PoLAR::Object3D(floorGeode.get());
	viewer.addObject3D(sol);
	sol->setEditOn();
	sol->translate(30, 0.35, -0.1);
	sol->scale(3.33);
	sol->setTransparencyOn();
	sol->setEditOff();

	viewer.show();

	app.connect(&app, SIGNAL(lastWindowClosed()), &app, SLOT(quit()));
	return app.exec();
}